===========================
Processing Module Reference
===========================

The ``vascusim.processing`` module provides utilities for analyzing and processing vascular geometries.

Geometry Processing
------------------

.. autofunction:: vascusim.processing.compute_curvature

.. autofunction:: vascusim.processing.compute_surface_area

.. autofunction:: vascusim.processing.compute_volume

.. autofunction:: vascusim.processing.extract_centerline

.. autofunction:: vascusim.processing.compute_branch_angles

Preprocessing Functions
----------------------

.. autofunction:: vascusim.processing.normalize_geometry

.. autofunction:: vascusim.processing.resample_geometry

.. autofunction:: vascusim.processing.filter_noise

.. autofunction:: vascusim.processing.compute_features

Parallel Processing
------------------

.. autofunction:: vascusim.processing.parallelize

.. autofunction:: vascusim.processing.worker_pool

.. autofunction:: vascusim.processing.process_batch

Module Contents
-------------

.. automodule:: vascusim.processing
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
---------

Geometry Submodule
~~~~~~~~~~~~~~~~~

.. automodule:: vascusim.processing.geometry
   :members:
   :undoc-members:
   :show-inheritance:

Preprocessing Submodule
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: vascusim.processing.preprocessing
   :members:
   :undoc-members:
   :show-inheritance:

Parallel Processing Submodule
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: vascusim.processing.parallel
   :members:
   :undoc-members:
   :show-inheritance: